@@ -100,15 +100,6 @@ class Scoreboard:
         """
         return iter(self.rows)
 
-    def __next__(self) -> ScoreboardRow:
-        """Returns the next row in the scorebaord.
-
-        Returns:
-          ScoreboardRow:
-            The next scoreboard row.
-        """
-        return next(self.rows)  # type: ignore
-
     def __repr__(self) -> str:
         """String representation of a board"""
         return f"Soln={self.rows[0].soln} ({len(self)} guesses)"
@@ -277,10 +268,10 @@ class HtmlScoreboardPrinter:
             num_left_str = str(num_left) if soln != guess else ""
 
             if has_dividers and row.n != prev_row:
-                row_divider = """<tr>
+                row_divider = """
+                <tr>
                     <td colspan="5" class="divider"><hr /></td>
-                </tr>
-                """
+                </tr>"""
                 row_strings.append(row_divider)
 
             row_template = f"""
@@ -290,8 +281,7 @@ class HtmlScoreboardPrinter:
                 <td><tt>{guess}</tt></td>
                 <td>{score}</td>
                 <td>{num_left_str}</td>
-            </tr>
-            """
+            </tr>"""
             row_strings.append(row_template)
             prev_row = row.n
 
@@ -308,8 +298,7 @@ class HtmlScoreboardPrinter:
             <th>Poss</th>
           </tr>
         </thead>
-        <tbody>
-          {all_rows}
+        <tbody>{all_rows}
         </tbody>
         </table>
         """
